#
# spec file for package ctranslate2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ctranslate2
Version:        4.6.0
%define lname libctranslate2-4
Release:        1.1
Summary:        Library for efficient inference with Transformer models
License:        MIT
URL:            https://github.com/OpenNMT/CTranslate2
Source:         CTranslate2-%version.tar.xz
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  openblas-devel
#BuildRequires:  libgmock-devel
BuildRequires:  nlohmann_json-devel
BuildRequires:  cpuinfo-devel
BuildRequires:  gmock
BuildRequires:  gtest
ExcludeArch:    %ix86 %arm

%description
CTranslate2 is a C++ and Python library for efficient inference with Transformer models.

NOTE: hardware accelaration is currently disabled in this package for license reasons

%package devel
Summary:        Development files for libctranslate2
Requires:       %lname

%description devel
Development files for libctranslate2 like cmake and header files.

%package -n %lname
Summary:        The ctranslate2 library

%description -n %lname
The ctranslate2 library

%prep
%autosetup -p1 -n CTranslate2-%version
rm -rf include/nlohmann/

%build
%cmake \
  -DBUILD_TESTS=ON \
  -DOPENBLAS_INCLUDE_DIR=/usr/include/openblas \
  -DOPENMP_RUNTIME=COMP \
  -DWITH_OPENBLAS=ON \
  -DWITH_MKL=OFF \
  -DWITH_RUY=ON

%cmake_build

%install
%cmake_install

%check
cd build
./tests/ctranslate2_test ../tests/data

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%license LICENSE
%doc CHANGELOG.md README.md
%doc docs examples
%_bindir/ct2-translator

%files devel
%_includedir/ctranslate2
%_includedir/half_float
%_libdir/cmake/ctranslate2
%_libdir/libctranslate2.so

%files -n %lname
%_libdir/libctranslate2.so.*

%changelog
* Mon May  5 2025 Adrian Schröter <adrian@suse.de>
- update to version 4.6.0
  New features
  * Pyhton 3.13 support
  * Support returning hidden vector in Wav2Vec2 and Wav2Vec2Bert Models
  * Add noexecstack linker flags
  * Support Qwen2
  * Eoleconv
  * Add support RobertModel
  Fixes and improvements
  * Prevent double library def
* Thu Nov  7 2024 Adrian Schröter <adrian@suse.de>
- update to version 4.5.0
  New features
  * Support Phi3
  * Support Mistral Nemo
  * Support Wav2Vec2Bert ASR
  Fixes and improvements
  * Upgrade to CUDNN9
  * Fix logits vocab
  * Update doc AWQ
* Wed Sep 25 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Tue Sep 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 4.4.0
  * *Removed**: Flash Attention support in the Python package due to
    significant package size increase with minimal
    performance gain.
  [#]## New features
  * Support Llama3
  * Support Gemma2
  * Add log probs for all tokens in vocab
  * Grouped conv1d
  [#]## Fixes and improvements
  * Some improvements in flash attention
  * Fix crash when using return_alternative on CUDA
  * Quantization AWQ GEMM + GEMV
* Thu Jul 11 2024 Adrian Schröter <adrian@suse.de>
- initial package of version 4.3.1
